@@ -1,18 +1,24 @@
 import os
 
-from maitai._azure import MaitaiAsyncAzureOpenAIClient as AsyncAzureOpenAI, MaitaiAzureOpenAIClient as AzureOpenAI
+from maitai._azure import (
+    MaitaiAsyncAzureOpenAIClient as AsyncAzureOpenAI,
+    MaitaiAzureOpenAIClient as AzureOpenAI,
+)
 from maitai._context import ContextManager
 from maitai._evaluator import Evaluator as Evaluator
 from maitai._inference import Inference as Inference
-from maitai._openai import Chat, MaitaiOpenAIClient as OpenAI
-from maitai._openai_async import MaitaiAsyncOpenAIClient as AsyncOpenAI
+from maitai._maitai import Chat, Maitai
+from maitai._maitai_async import MaitaiAsync
 
 chat = Chat()
 context = ContextManager()
+AsyncOpenAI = MaitaiAsync
+OpenAI = Maitai
 
 
 def initialize(api_key):
     from maitai._config import config
+
     config.initialize(api_key)
 
 
